<template>
  <b-modal
    ref="myModalRef"
    :title="title"
    size="lg"
    ok-title="确定"
    cancel-title="取消"
    @ok="handleSave"
    @cancel="hideModal"
  >
    <div class="ml10">
      <span>姓名：</span>
      <b-input
        v-model="searchValue"
        style="width: 200px; display: inline-block"
        placeholder="请输入姓名"
        @change.native="handleSearch"
      />
      <b-btn
        variant="primary"
        @click="handleSearch"
      >
        搜索
      </b-btn>
    </div>
    <div class="row pt-3" style="margin-left: 0; margin-right: 0">
      <div
        :key="item.id"
        v-for="item in modelList"
        class="col-md-6 col-xl-4"
      >
        <b-card
          class="card-condenced mb-4"
          body-class="media align-items-center"
        >
          <b-check
            class="file-item-checkbox"
            :checked="selected.includes(item)"
            @change="toggleSelect($event, item)"
          />
          <httpImg :src="item.photos" style="width: 50px" />
          <div class="media-body ml-3">
            <a
              href="javascript:void(0)"
              class="text-dark font-weight-semibold mb-2"
            >
              {{item.name}}
            </a>
          </div>
        </b-card>
      </div>
    </div>
    <div class="fr">
      <b-pagination
        class="ml10"
        v-if="total"
        size="md"
        :total-rows="total"
        v-model="currentPage"
        :per-page="length"
        @change="changePage"
      />
    </div>
  </b-modal>
</template>

<style src="@/vendor/styles/pages/file-manager.scss" lang="scss"></style>

<script>
/**
 * 选择人员
 * @param { String } title 弹框名 默认 - 请选择人员关系
 * @param { String } orgId 机构id
 */

import { getUserList } from '../../server/personnel.js'

export default {
  props: {
    title: {
      type: String,
      default: '请选择人员关系'
    }
  },
  data: () => ({
    modelList: [],
    total: 0,
    length: 9,
    currentPage: 1,
    searchValue: '',
    selected: [],
    focused: null,
    dropdownOpened: null
  }),
  computed: {
    orgId() {
      return this.$store.getters.basicUserInfo.orgId
    }
  },
  methods: {
    showModal() {
      this.$refs.myModalRef.show()
      this.getRelation()
    },
    hideModal() {
      this.$refs.myModalRef.hide()
    },
    // * 获取数据
    async getRelation() {
      const res = await getUserList({
        orgId: this.orgId,
        id: 1,
        length: this.length,
        start: this.length * (this.currentPage - 1),
        type: '',
        isAll: 0,
        name: this.searchValue
      })
      if (res) {
        this.modelList = res.data
        this.total = res.total
      }
    },
    // * 分页器设置
    changePage(e) {
      this.currentPage = e
      this.getRelation()
    },
    // * 搜索
    handleSearch() {
      this.currentPage = 1
      this.getRelation()
    },
    // * 选择
    toggleSelect(checked, item) {
      if (checked) {
        this.selected = [item]
      } else {
        this.selected.splice(this.selected.indexOf(item), 1)
      }
    },
    // * 保存
    handleSave() {
      this.$emit('relationData', this.selected)
      this.selected = []
      this.hideModal()
    }
  }
}
</script>
